@@ -214,7 +214,7 @@ static DrawWindow *X11InitWindow()
     XCreateGC(display, new_window->drawable, gc_valuemask, &gc_values);
 
   /* create GCs for line drawing (black and white) */
-  for(i=0; i<2; i++)
+  for (i = 0; i < 2; i++)
   {
     gc_values.graphics_exposures = False;
     gc_values.foreground = (i ? pen_fg : pen_bg);
@@ -399,7 +399,7 @@ inline Pixel X11GetPixel(Bitmap *bitmap, int x, int y)
 			  AllPlanes, ZPixmap);
   pixel_value = XGetPixel(pixel_image, 0, 0);
 
-  XDestroyImage(pixel_image);
+  X11DestroyImage(pixel_image);
 
   return pixel_value;
 }
@@ -423,6 +423,20 @@ inline Pixel X11GetPixelFromRGB(unsigned int color_r, unsigned int color_g,
 }
 #endif	/* TARGET_X11_NATIVE */
 
+inline void X11DestroyImage(XImage *ximage)
+{
+#if defined(TARGET_X11_NATIVE)
+  /* this seems to be needed for OS/2, but does not hurt on other platforms */
+  if (ximage->data != NULL)
+  {
+    free(ximage->data);
+    ximage->data = NULL;
+  }
+#endif	/* TARGET_X11_NATIVE */
+
+  XDestroyImage(ximage);
+}
+
 
 /* ------------------------------------------------------------------------- */
 /* mouse pointer functions                                                   */
